@@ -28,6 +28,7 @@ static struct
 	int batch_mode;
 	int panic_mode;
 	int allow_null;
+	int use_cluster_disjuncts;
 	int echo_on;
 	int cost_model;
 	int screen_width;
@@ -66,6 +67,7 @@ static Switch default_switches[] =
    {"max-length", 0, "Maximum sentence length",         &local.max_sentence_length},
    {"memory",     0, "Max memory allowed",              &local.memory},
    {"null",       1, "Null links",                      &local.allow_null},
+   {"cluster",    1, "Use clusters to loosen parsing",  &local.use_cluster_disjuncts},
    {"null-block", 0, "Size of blocks with null cost 1", &local.null_block},
    {"panic",      1, "Use of \"panic mode\"",           &local.panic_mode},
    {"postscript", 1, "Generate postscript output",      &local.display_postscript},
@@ -334,6 +336,7 @@ static void put_opts_in_local_vars(Parse_Options opts)
 	local.panic_mode = parse_options_get_panic_mode(opts);
 	local.screen_width = parse_options_get_screen_width(opts);
 	local.allow_null = parse_options_get_allow_null(opts);
+	local.use_cluster_disjuncts = parse_options_get_use_cluster_disjuncts(opts);
 	local.screen_width = parse_options_get_screen_width(opts);
 	local.display_on = parse_options_get_display_on(opts);
 	local.display_postscript = parse_options_get_display_postscript(opts);
@@ -363,6 +366,7 @@ static void put_local_vars_in_opts(Parse_Options opts)
 	parse_options_set_panic_mode(opts, local.panic_mode);
 	parse_options_set_screen_width(opts, local.screen_width);
 	parse_options_set_allow_null(opts, local.allow_null);
+	parse_options_set_use_cluster_disjuncts(opts, local.use_cluster_disjuncts);
 	parse_options_set_screen_width(opts, local.screen_width);
 	parse_options_set_display_on(opts, local.display_on);
 	parse_options_set_display_postscript(opts, local.display_postscript);
