@@ -12,6 +12,7 @@
 /*************************************************************************/
 
 #include <link-grammar/api.h>
+#include "disjunct-utils.h"
 
 void free_deletable(Sentence sent)
 {
@@ -28,6 +29,17 @@ void free_deletable(Sentence sent)
 	}
 }
 
+/**
+ *  Returns true if the range lw...rw inclusive contains a conjunction 
+ */
+static int conj_in_range(Sentence sent, int lw, int rw)
+{
+	for (;lw < rw+1; lw++) {
+		if (sent->is_conjunction[lw]) return TRUE;
+	}
+	return FALSE;
+}
+
 /**
  * Initialize the array deletable[i][j] to indicate if the words
  * i+1...j-1 could be non existant in one of the multiple linkages.  This
@@ -262,6 +274,22 @@ void free_sentence_expressions(Sentence sent)
   }
 }
 
+
+/**
+ * Return true if the sentence contains a conjunction.  Assumes
+ * is_conjunction[] has been initialized.
+ */
+static int sentence_contains_conjunction(Sentence sent)
+{
+	int w;
+	if (NULL == sent->is_conjunction) return FALSE;
+
+	for (w=0; w<sent->length; w++) {
+		if (sent->is_conjunction[w]) return TRUE;
+	}
+	return FALSE;
+}
+
 void free_sentence_disjuncts(Sentence sent)
 {
 	int i;
